summaryrefslogtreecommitdiff
path: root/src/wx
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-11-06 22:43:52 +0000
committerCarl Hetherington <cth@carlh.net>2018-11-06 22:43:52 +0000
commited68bfad5c795afb342c5228f3c1dc7770a6d646 (patch)
treeebf0a5b7f2c9b1636c498715f0f7aaaf8dcc98f7 /src/wx
parente5b744922fb6aed65ec13f22a9de0c86dd1bd561 (diff)
Switch PlayerVideo::always_rgb to a new ::force and use it in FFmpegFileEncoder.
Diffstat (limited to 'src/wx')
-rw-r--r--src/wx/film_viewer.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/wx/film_viewer.cc b/src/wx/film_viewer.cc
index 0a72b5a1d..019633720 100644
--- a/src/wx/film_viewer.cc
+++ b/src/wx/film_viewer.cc
@@ -267,12 +267,12 @@ FilmViewer::display_player_video ()
* The content's specified colour conversion indicates the colourspace
* which the content is in (according to the user).
*
* PlayerVideo::image (bound to PlayerVideo::always_rgb) will take the source
* image and convert it (from whatever the user has said it is) to RGB.
*/
_frame = _player_video.first->image (
- bind (&PlayerVideo::always_rgb, _1),
+ bind (&PlayerVideo::force, _1, AV_PIX_FMT_RGB24),
false, true
);
@@ -267,12 +267,12 @@ FilmViewer::display_player_video ()
* which the content is in (according to the user).
*
- * PlayerVideo::image (bound to PlayerVideo::always_rgb) will take the source
+ * PlayerVideo::image (bound to PlayerVideo::force) will take the source
* image and convert it (from whatever the user has said it is) to RGB.
*/